﻿------------------------------------------------------------------------------------------
--Setup the Class Power-------------------------------------------------------------------
------------------------------------------------------------------------------------------
local SN, L, F, T, M, _ = unpack(select(2,...))

local UnitHasVehicleUI = UnitHasVehicleUI
local unpack = unpack

SN["classMaxResourceBar"] = {
	["DEATHKNIGHT"] = 6,
	["PALADIN"] = 5,
	["WARLOCK"] = 4,
	["PRIEST"] = 3,
	["MONK"] = 5,
	["MAGE"] = 6,
}

function SN:ClassPower()
	F.classpower = CreateFrame("Frame", nil, UIParent)
	F.classpower:SetPoint(unpack(SN.data.profile.frames.classpower))
	F.classpower:SetSize(SN.data.profile.classResources.width, SN.data.profile.classResources.height)
	F.classpower.frame = {}
	F.classpower.name = "Class Power"
	F.classpower.value = F.classpower:CreateFontString(nil, "OVERLAY")
	F.classpower.value:SetPoint("CENTER", F.classpower, "CENTER", 4, 0)
	F.classpower.value:SetFontObject(GameFontNormal)
	F.classpower.value:SetJustifyH("CENTER")
	F.classpower.value:SetShadowOffset(1, -1)
	
	F.classpower:RegisterEvent("PLAYER_ENTERING_WORLD")
	F.classpower:RegisterEvent("UNIT_DISPLAYPOWER")
		
	F.classpower:SetScript("OnEvent", function(self, event, ...)
		if event == "PLAYER_ENTERING_WORLD" then
			SN:SetupRunes()
			SN:SetupCombo()
			SN:SetupHoly()
			SN:SetupEclipse()
			SN:SetupChi()
			SN:SetupSOrbs()
			SN:SetupShards()

			if (IsAddOnLoaded("ElvUI")) then
				SN:ElvOverride()
			end
			if SN.data.profile.classResources.enable then
				if SN.playerClass == "PALADIN" then
					PaladinPowerBar:Hide()
					PaladinPowerBar:UnregisterAllEvents()
				end

				if SN.playerClass == "DEATHKNIGHT" then
					RuneFrame:Hide()
					RuneFrame:UnregisterAllEvents()
				end

				if SN.playerClass == "ROGUE" or "DRUID" then	
					ComboFrame:Hide()
					ComboFrame:UnregisterAllEvents()
				end

				if SN.playerClass == "DRUID" then
					EclipseBarFrame:Hide()
					EclipseBarFrame:UnregisterAllEvents()
				end

				if SN.playerClass == "MONK" then
					MonkHarmonyBar:Hide()
					MonkHarmonyBar:UnregisterAllEvents()
				end
				
				if SN.playerClass == "PRIEST" then
					PriestBarFrame:Hide()
					PriestBarFrame:UnregisterAllEvents()
				end

				if SN.playerClass == "WARLOCK" then
					WarlockPowerFrame:Hide()
					WarlockPowerFrame:UnregisterAllEvents()
				end
			end
		end

		if event == "UNIT_DISPLAYPOWER" then
			if self.frame ~= nil then
				if UnitHasVehicleUI("player") and self.frame ~= nil then
					for i = 1, #self.frame do
						self.frame[i]:Hide()
					end
				else
					if SN.data.profile.classResources.enable and self.frame ~= nil then
						for i = 1, #self.frame do
							self.frame[i]:Show()
						end
					end
				end
			end
		end
	end)

	if SN.data.profile.classResources.enable == false then
		SN:ClassDisable()		
	end
end

function SN:ClassResize()
	local BORDER = 2
	local MAX_HOLY_POWER = 5
	local MAX_COMBO_POINTS = MAX_COMBO_POINTS
	local CLASSBAR_WIDTH = F.classpower:GetWidth() - (BORDER*2)
	local maxRune = SN['classMaxResourceBar']["DEATHKNIGHT"]
	local maxChi = SN['classMaxResourceBar']["MONK"]
	
	F.classpower:SetSize(SN.data.profile.classResources.width, SN.data.profile.classResources.height)

	if SN.playerClass == "DEATHKNIGHT" then
		F.classpower.runes:SetSize(CLASSBAR_WIDTH, F.classpower:GetHeight())
		for i = 1, maxRune do
			F.classpower.runes[i]:SetSize((F.classpower.runes:GetWidth() - 15) / 6, F.classpower.runes:GetHeight() - 6)
		end
	elseif SN.playerClass == "PALADIN" then
		F.classpower.holypower:SetSize(CLASSBAR_WIDTH, F.classpower:GetHeight())
		for i = 1, MAX_HOLY_POWER do
			F.classpower.holypower[i]:SetSize((F.classpower.holypower:GetWidth() - 16) / MAX_HOLY_POWER, F.classpower.holypower:GetHeight() - 6)
		end
	elseif SN.playerClass == "DRUID" or SN.playerClass == "ROGUE" then
		if SN.playerClass == "DRUID" and GetSpecialization() == 1 then
			F.classpower.eclipse:SetSize(F.classpower:GetWidth(), F.classpower:GetHeight())
			F.classpower.eclipse.lunar:SetSize(F.classpower.eclipse:GetWidth() - 1, F.classpower.eclipse:GetHeight() - 1)
			F.classpower.eclipse.solar:SetSize(F.classpower.eclipse:GetWidth() - 1, F.classpower.eclipse:GetHeight() - 1)
		end
		F.classpower.points:SetSize(CLASSBAR_WIDTH, F.classpower:GetHeight())
		for i = 1, MAX_COMBO_POINTS do
			F.classpower.points[i]:SetSize((F.classpower.points:GetWidth() - 16) / MAX_COMBO_POINTS, F.classpower.points:GetHeight() - 6)
		end
	elseif SN.playerClass == "MONK" then
		F.classpower.chi:SetSize(CLASSBAR_WIDTH, F.classpower:GetHeight())
		local curChi = UnitPowerMax("player", SPELL_POWER_CHI)

		for i = 1, curChi do
			F.classpower.chi[i]:SetSize((F.classpower.chi:GetWidth() - 16) / curChi, F.classpower.chi:GetHeight() - 6)
		end
	elseif SN.playerClass == "PRIEST" then
		F.classpower.shadoworbs:SetSize(CLASSBAR_WIDTH, F.classpower:GetHeight())
		local curOrbs = PRIEST_BAR_NUM_ORBS

		for i = 1, curOrbs do
			F.classpower.shadoworbs[i]:SetSize((F.classpower.shadoworbs:GetWidth() - 16) / curOrbs, F.classpower.shadoworbs:GetHeight() - 6)
		end
	elseif SN.playerClass == "WARLOCK" then
		local spec = GetSpecialization()
		local number = F.classpower.shards.number

		F.classpower.shards:SetSize(CLASSBAR_WIDTH, F.classpower:GetHeight())

		if spec == 1 or 3 then
			for i = 1, number do
				F.classpower.shards[i]:SetSize((F.classpower.shards:GetWidth() - 20) / number, F.classpower.shards:GetHeight() - 6)
			end
		elseif spec == 2 then
			F.classpower.shards[1]:SetSize((F.classpower.shards:GetWidth() - 11), F.classpower.shards:GetHeight() - 6)
		end
	end
end	

function SN:BlizzClassPower(info, value)

	if SN.playerClass == "PALADIN" then
		local visible = PaladinPowerBar:IsVisible()
		if SN.data.profile.classResources[info[#info]] then
			if visible then
				PaladinPowerBar:Hide()
				PaladinPowerBar:UnregisterAllEvents()
			end
		elseif SN.data.profile.classResources[info[#info]] == false then
			if not visible then
				PaladinPowerBar:Show()
				PaladinPowerBar:GetScript("OnLoad")(PaladinPowerBar)
			end
		end
    end

	if SN.playerClass == "DEATHKNIGHT" then
		local visible = RuneFrame:IsVisible()
		if SN.data.profile.classResources[info[#info]] then
			if visible then
				RuneFrame:Hide()
				RuneFrame:UnregisterAllEvents()
			end
		elseif SN.data.profile.classResources[info[#info]] == false then
			if not visible then
				RuneFrame:Show()
				RuneFrame:GetScript("OnLoad")(RuneFrame)
			end
		end
	end

	if SN.playerClass == "ROGUE" or "DRUID" then
		local visible = ComboFrame:IsVisible()
		if SN.data.profile.classResources[info[#info]] then
			if visible then
				ComboFrame:Hide()
				ComboFrame:UnregisterAllEvents()
			end
		elseif SN.data.profile.classResources[info[#info]] == false then
			if not visible then
				ComboFrame:Show()
				ComboFrame:GetScript("OnLoad")(ComboFrame)
			end
		end
	end

	if SN.playerClass == "DRUID" then
		local spec = GetSpecialization()
		local visible = EclipseBarFrame:IsVisible()
		if SN.data.profile.classResources[info[#info]] and spec == 1 then
			if visible then
				EclipseBarFrame:Hide()
				EclipseBarFrame:UnregisterAllEvents()
			end
		elseif SN.data.profile.classResources[info[#info]] == false and spec == 1 then
			if not visible then
				EclipseBarFrame:Show()
				EclipseBarFrame:GetScript("OnLoad")(EclipseBarFrame)
			end
		end
	end

	if SN.playerClass == "MONK" then
		local visible = MonkHarmonyBar:IsVisible()
		if SN.data.profile.classResources[info[#info]] then
			if visible then
				MonkHarmonyBar:Hide()
				MonkHarmonyBar:UnregisterAllEvents()
			end
		elseif SN.data.profile.classResources[info[#info]] == false then
			if not visible then
				MonkHarmonyBar:Show()
				MonkHarmonyBar:GetScript("OnLoad")(MonkHarmonyBar)
			end
		end
	end

	if SN.playerClass == "WARLOCK" then
		local visible = WarlockPowerFrame:IsVisible()
		if SN.data.profile.classResources[info[#info]] then
			if visible then
				WarlockPowerFrame:Hide()
				WarlockPowerFrame:UnregisterAllEvents()
			end
		elseif SN.data.profile.classResources[info[#info]] == false then
			if not visible then
				WarlockPowerFrame:Show()
				WarlockPowerFrame:GetScript("OnLoad")(WarlockPowerFrame)
			end
		end
	end

	if SN.playerClass == "PRIEST" then
		local visible = PriestBarFrame:IsVisible()
		if SN.data.profile.classResources[info[#info]] then
			if visible then
				PriestBarFrame:Hide()
				PriestBarFrame:UnregisterAllEvents()
			end
		elseif SN.data.profile.classResources[info[#info]] == false then
			if not visible then
				PriestBarFrame:Show()
				PriestBarFrame:GetScript("OnLoad")(PriestBarFrame)
			end
		end
	end
end

function SN:ClassEnable()
	F.classpower:Show()
end

function SN:ClassDisable()
	F.classpower:Hide()
end